summaryrefslogtreecommitdiffstats
path: root/include/cppuhelper/implbase1.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-20 11:02:14 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-10-21 06:36:39 +0000
commit08233bd25849cc7d5d092aa073362c7766cbcc19 (patch)
treeef27b8d8b00e531e31eea084f7cce81b6cb0bcb2 /include/cppuhelper/implbase1.hxx
parentcom::sun::star->css in include/cppu (diff)
downloadcore-08233bd25849cc7d5d092aa073362c7766cbcc19.tar.gz
core-08233bd25849cc7d5d092aa073362c7766cbcc19.zip
com::sun::star->css in include/cppuhelper
Change-Id: I3d9dcd4cd756a3f0d9cedd894377a117c9dbeecc Reviewed-on: https://gerrit.libreoffice.org/19486 Reviewed-by: Noel Grandin <noelgrandin@gmail.com> Tested-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'include/cppuhelper/implbase1.hxx')
-rw-r--r--include/cppuhelper/implbase1.hxx78
1 files changed, 39 insertions, 39 deletions
diff --git a/include/cppuhelper/implbase1.hxx b/include/cppuhelper/implbase1.hxx
index 4180c9d63db5..6a518263c92a 100644
--- a/include/cppuhelper/implbase1.hxx
+++ b/include/cppuhelper/implbase1.hxx
@@ -45,7 +45,7 @@ namespace cppu
{ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 },
{
CPPUHELPER_DETAIL_TYPEENTRY(Ifc1),
- CPPUHELPER_DETAIL_TYPEENTRY(com::sun::star::lang::XTypeProvider)
+ CPPUHELPER_DETAIL_TYPEENTRY(css::lang::XTypeProvider)
}
};
return reinterpret_cast< class_data * >(&s_cd);
@@ -54,7 +54,7 @@ namespace cppu
/// @endcond
/** Implementation helper implementing interface com::sun::star::lang::XTypeProvider
and method XInterface::queryInterface(), but no reference counting.
@derive
@@ -64,16 +64,16 @@ namespace cppu
*/
template< class Ifc1 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE ImplHelper1
- : public com::sun::star::lang::XTypeProvider
+ : public css::lang::XTypeProvider
, public Ifc1
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData1 < Ifc1, ImplHelper1<Ifc1> > > {};
public:
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_query( rType, cd::get(), this ); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getTypes( cd::get() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
#if !defined _MSC_VER // public -> protected changes mangled names there
@@ -81,9 +81,9 @@ namespace cppu
#endif
~ImplHelper1() throw () {}
};
- /** Implementation helper implementing interfaces com::sun::star::lang::XTypeProvider and
- com::sun::star::uno::XInterface which supports weak mechanism to be held weakly
- (supporting com::sun::star::uno::XWeak through ::cppu::OWeakObject).
+ /** Implementation helper implementing interfaces css::lang::XTypeProvider and
+ css::uno::XInterface which supports weak mechanism to be held weakly
+ (supporting css::uno::XWeak through ::cppu::OWeakObject).
@derive
Inherit from this class giving your interface(s) to be implemented as template argument(s).
@@ -96,27 +96,27 @@ namespace cppu
template< class Ifc1 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE SAL_DLLPUBLIC_EXPORT WeakImplHelper1
: public OWeakObject
- , public com::sun::star::lang::XTypeProvider
+ , public css::lang::XTypeProvider
, public Ifc1
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData1< Ifc1, WeakImplHelper1< Ifc1 > > > {};
public:
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakImplHelper_query( rType, cd::get(), this, static_cast<OWeakObject *>(this) ); }
virtual void SAL_CALL acquire() throw () SAL_OVERRIDE
{ OWeakObject::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ OWeakObject::release(); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakImplHelper_getTypes( cd::get() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
- /** Implementation helper implementing interfaces com::sun::star::lang::XTypeProvider and
- com::sun::star::uno::XInterface which supports weak mechanism to be held weakly
- (supporting com::sun::star::uno::XWeak through ::cppu::OWeakAggObject).
+ /** Implementation helper implementing interfaces css::lang::XTypeProvider and
+ css::uno::XInterface which supports weak mechanism to be held weakly
+ (supporting css::uno::XWeak through ::cppu::OWeakAggObject).
In addition, it supports also aggregation meaning object of this class can be aggregated
- (com::sun::star::uno::XAggregation through ::cppu::OWeakAggObject).
+ (css::uno::XAggregation through ::cppu::OWeakAggObject).
If a delegator is set (this object is aggregated), then incoming queryInterface()
calls are delegated to the delegator object. If the delegator does not support the
demanded interface, it calls queryAggregation() on its aggregated objects.
@@ -128,33 +128,33 @@ namespace cppu
template< class Ifc1 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE WeakAggImplHelper1
: public OWeakAggObject
- , public com::sun::star::lang::XTypeProvider
+ , public css::lang::XTypeProvider
, public Ifc1
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData1< Ifc1, WeakAggImplHelper1< Ifc1 > > > {};
public:
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return OWeakAggObject::queryInterface( rType ); }
- virtual com::sun::star::uno::Any SAL_CALL queryAggregation( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryAggregation( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakAggImplHelper_queryAgg( rType, cd::get(), this, static_cast<OWeakAggObject *>(this) ); }
virtual void SAL_CALL acquire() throw () SAL_OVERRIDE
{ OWeakAggObject::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ OWeakAggObject::release(); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakAggImplHelper_getTypes( cd::get() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
- /** Implementation helper implementing interfaces com::sun::star::lang::XTypeProvider and
- com::sun::star::uno::XInterface inherting from a BaseClass.
+ /** Implementation helper implementing interfaces css::lang::XTypeProvider and
+ css::uno::XInterface inherting from a BaseClass.
All acquire() and release() calls are delegated to the BaseClass. Upon queryInterface(),
if a demanded interface is not supported by this class directly, the request is
delegated to the BaseClass.
@attention
- The BaseClass has to be complete in a sense, that com::sun::star::uno::XInterface
- and com::sun::star::lang::XTypeProvider are implemented properly. The
+ The BaseClass has to be complete in a sense, that css::uno::XInterface
+ and css::lang::XTypeProvider are implemented properly. The
BaseClass must have at least one ctor that can be called with six or
fewer arguments, of which none is of non-const reference type.
@@ -197,9 +197,9 @@ namespace cppu
BaseClass(arg1, arg2, arg3, arg4, arg5, arg6) {}
public:
ImplInheritanceHelper1() {}
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{
- com::sun::star::uno::Any aRet( ImplHelper_queryNoXInterface( rType, cd::get(), this ) );
+ css::uno::Any aRet( ImplHelper_queryNoXInterface( rType, cd::get(), this ) );
if (aRet.hasValue())
return aRet;
return BaseClass::queryInterface( rType );
@@ -208,20 +208,20 @@ namespace cppu
{ BaseClass::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ BaseClass::release(); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplInhHelper_getTypes( cd::get(), BaseClass::getTypes() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
- /** Implementation helper implementing interfaces com::sun::star::lang::XTypeProvider and
- com::sun::star::uno::XInterface inherting from a BaseClass.
+ /** Implementation helper implementing interfaces css::lang::XTypeProvider and
+ css::uno::XInterface inherting from a BaseClass.
All acquire(), release() and queryInterface() calls are delegated to the BaseClass.
Upon queryAggregation(), if a demanded interface is not supported by this class directly,
the request is delegated to the BaseClass.
@attention
- The BaseClass has to be complete in a sense, that com::sun::star::uno::XInterface,
- com::sun::star::uno::XAggregation and com::sun::star::lang::XTypeProvider
+ The BaseClass has to be complete in a sense, that css::uno::XInterface,
+ css::uno::XAggregation and css::lang::XTypeProvider
are implemented properly. The BaseClass must have at least one ctor
that can be called with six or fewer arguments, of which none is of
non-const reference type.
@@ -265,11 +265,11 @@ namespace cppu
BaseClass(arg1, arg2, arg3, arg4, arg5, arg6) {}
public:
AggImplInheritanceHelper1() {}
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{ return BaseClass::queryInterface( rType ); }
- virtual com::sun::star::uno::Any SAL_CALL queryAggregation( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryAggregation( css::uno::Type const & rType ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
- com::sun::star::uno::Any aRet( ImplHelper_queryNoXInterface( rType, cd::get(), this ) );
+ css::uno::Any aRet( ImplHelper_queryNoXInterface( rType, cd::get(), this ) );
if (aRet.hasValue())
return aRet;
return BaseClass::queryAggregation( rType );
@@ -278,9 +278,9 @@ namespace cppu
{ BaseClass::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ BaseClass::release(); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException) SAL_OVERRIDE
{ return ImplInhHelper_getTypes( cd::get(), BaseClass::getTypes() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
}
@@ -54,7 +54,7 @@ namespace cppu
/// @endcond
- /** Implementation helper implementing interface com::sun::star::lang::XTypeProvider
+ /** Implementation helper implementing interface css::lang::XTypeProvider
and method XInterface::queryInterface(), but no reference counting.